﻿using System;
using System.Collections.Generic;
using System.Globalization;
using System.IO;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;

namespace XDG_screenshot
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
        }

        public static void TakeScreenshot(string fileName, FrameworkElement element)
        {
            string imageExtension = null;
            imageExtension = new FileInfo(fileName).Extension.ToLower(CultureInfo.InvariantCulture);
            BitmapEncoder imgEncoder = null;

            string desktopPath = Environment.GetFolderPath(Environment.SpecialFolder.Desktop);

            switch (imageExtension)
            {
                case ".bmp": imgEncoder = new BmpBitmapEncoder(); break;
                case ".jpg":
                case ".jpeg": imgEncoder = new JpegBitmapEncoder(); break;
                case ".png": imgEncoder = new PngBitmapEncoder(); break;
                case ".gif": imgEncoder = new GifBitmapEncoder(); break;
                case ".tif":
                case ".tiff": imgEncoder = new TiffBitmapEncoder(); break;
                case ".wdp": imgEncoder = new WmpBitmapEncoder(); break;
                default: imgEncoder = new BmpBitmapEncoder(); break;
            }

            if (element != null)
            {
                RenderTargetBitmap bmpSource = new RenderTargetBitmap((int)element.ActualWidth, (int)element.ActualHeight, 96, 96, PixelFormats.Pbgra32);
                bmpSource.Render(element);
                imgEncoder.Frames.Add(BitmapFrame.Create(bmpSource));

                using (Stream stream = File.Create(desktopPath + @"\" + fileName))
                {
                    imgEncoder.Save(stream);
                    stream.Close();
                }
            }
        }

        private void Button_Click(object sender, RoutedEventArgs e)
        {
            try
            {
                TakeScreenshot("xamDataGrid_screenshot.png", xdg);
            }
            catch (Exception exc)
            {
                MessageBox.Show("An exception has been thrown while creating a screenshot: " + exc.Message);
            }

            MessageBox.Show("Screenshot taken and saved on Desktop.");
        }
    }
}
